Mixed-Up Code Exercises
------------------------

.. selectquestion:: Pictures1_v2_sq
   :fromid: mixedupcode_pictures_pp1, mixedupcode_pictures_ac1
   :toggle:

.. selectquestion:: Pictures2_v2_sq
   :fromid: mixedupcode_pictures_pp2, mixedupcode_pictures_ac2
   :toggle:

.. selectquestion:: Pictures3_v2_sq
   :fromid: mixedupcode_pictures_pp3, mixedupcode_pictures_ac3
   :toggle:

.. selectquestion:: Pictures4_v2_sq
   :fromid: mixedupcode_pictures_pp4, mixedupcode_pictures_ac4
   :toggle:

.. selectquestion:: Pictures5_v2_sq
   :fromid: mixedupcode_pictures_pp_5, mixedupcode_pictures_ac5
   :toggle:

.. selectquestion:: Pictures6_v2_sq
   :fromid: mixedupcode_pictures_pp6, mixedupcode_pictures_ac6
   :toggle:

.. selectquestion:: Pictures7_v2_sq
   :fromid: mixedupcode_pictures_pp_7, mixedupcode_pictures_ac7
   :toggle:

.. selectquestion:: Pictures8_v2_sq
   :fromid: mixedupcode_pictures_pp8, mixedupcode_pictures_ac8
   :toggle:

.. selectquestion:: Pictures9_v2_sq
   :fromid: mixedupcode_pictures_pp9, mixedupcode_pictures_ac9
   :toggle:

.. selectquestion:: Pictures10_v2_sq
   :fromid: mixedupcode_pictures_pp10, mixedupcode_pictures_ac10
   :toggle:
